@@ -825,7 +825,7 @@ def validate_configs(config: CLIContext, config_dir: str) -> None:
 @cli.command()
 @config_validation_options
 @click.option("--pin", type=bool, required=False, help="Whether to pin the model or not")
-@click.option("--force-primary", is_flag=True, default=False, help="Make this model current")
+@click.option("--force-primary", is_flag=True, default=None, help="Make this model current")
 @pass_config
 @click.pass_context
 @exception_handler
