@@ -117,7 +117,14 @@ class BackendInterface(BaseInterface):  # noqa: D
     ) -> requests.Response:  # noqa: D
         try:
             return upload_configs(
-                mode, self.auth_header, repo, branch, commit, config_dir, is_current, self.rest_api_url
+                mode=mode,
+                auth_header=self.auth_header,
+                repo=repo,
+                branch=branch,
+                commit=commit,
+                config_dir=config_dir,
+                is_current=is_current,
+                api_url=self.rest_api_url
             )
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
