@@ -182,9 +182,9 @@ class MQLClient:
         model_key = self.get_model_key(model_key_id) if model_key_id else None
         return sorted(self.context.mql_client.get_materializations(model_key), key=lambda m: m.name)
 
-    def commit_configs(self, config_dir: str) -> ModelKey:
+    def commit_configs(self, config_dir: str, is_current: Optional[bool] = None) -> ModelKey:
         """Validates and commits yaml transform configs in the provided directory. Returns a ModelKey object."""
-        return self.context.backend_client.commit_configs(config_dir)
+        return self.context.backend_client.commit_configs(config_dir, is_current)
 
     def validate_configs(self, config_dir: str) -> Tuple[str, str, str]:
         """Finds and validates yaml transform configs in the provided directory. Returns a tuple (repo, branch, commit)"""
@@ -262,11 +262,18 @@ class MQLClient:
         return self.context.backend_client.get_latest_mql_server_image()
 
     def get_dimension_values(
-        self, metric_name: str, dimension_name: str, model_key_id: Optional[int] = None
+        self,
+        metric_name: str,
+        dimension_name: str,
+        model_key_id: Optional[int] = None,
+        page_number: Optional[int] = None,
+        page_size: Optional[int] = None,
     ) -> List[str]:
         """Retrieves a list of dimension values given a [metric_name, dimension_name]."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
-        return self.context.mql_client.get_dimension_values(metric_name, dimension_name, model_key=model_key)
+        return self.context.mql_client.get_dimension_values(
+            metric_name, dimension_name, model_key=model_key, page_number=page_number, page_size=page_size
+        )
 
     def list_dimensions(self, model_key_id: Optional[int] = None) -> Dict[str, Dimension]:
         """Retrieves a list of all Dimension objects."""
